==> ark-21.08.1.tar.xz: ark-21.08.1/plugins/libsinglefileplugin/kerfuffle_libzstd.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the zstd algorithm",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «zstd»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem zstd",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem zstd-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο zstd",
        "Description[en_GB]": "Open and extract single files compressed with the zstd algorithm",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo zstd",
        "Description[eu]": "Ireki eta erauzi zstd algoritmoarekin konprimatutako fitxategi bakunak",
        "Description[fr]": "Ouvrir et extraire des fichiers uniques compressés avec l'algorithme « zstd »",
        "Description[ia]": "Aperir e extraher singule files comprimite con le algorithmo zstd",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo zstd",
        "Description[ko]": "zstd 알고리즘으로 압축된 단일 파일 열고 풀기",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het zstd-algoritme",
        "Description[pl]": "Otwiera i wypakowuje pojedyncze pliki spakowane algorytmem zstd",
        "Description[pt_BR]": "Abrir e extrair arquivos individuais compactados com o algoritmo zstd",
        "Description[ro]": "Deschide și extrage fișiere singulare comprimate cu algoritmul zstd",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму zstd",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom zstd",
        "Description[sl]": "Odpri in razširi posamezne datoteke stisnjene z algoritmom zstd",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med zstd-algoritmen",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму zstd",
        "Description[x-test]": "xxOpen and extract single files compressed with the zstd algorithmxx",
        "Description[zh_CN]": "打开和解压 zstd 算法压缩的单个文件",
        "Id": "kerfuffle_libzstd",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Zstd plugin",
        "Name[ca]": "Connector del Zstd",
        "Name[cs]": "Modul pro zstd",
        "Name[de]": "Zstd-Modul",
        "Name[el]": "Πρόσθετο zstd",
        "Name[en_GB]": "Zstd plugin",
        "Name[es]": "Complemento Zstd",
        "Name[eu]": "Zstd plugina",
        "Name[fr]": "Module externe « Zstd »",
        "Name[ia]": "Plugin de Zstd",
        "Name[it]": "Estensione zstd",
        "Name[ko]": "Zstd 플러그인",
        "Name[nl]": "Zstd-plug-in",
        "Name[pl]": "Wtyczka Zstd",
        "Name[pt_BR]": "Plugin Zstd",
        "Name[ro]": "Extensie Zstd",
        "Name[ru]": "Модуль Zstd",
        "Name[sk]": "Zstd plugin",
        "Name[sl]": "Vstavek Zstd",
        "Name[sv]": "Zstd-insticksprogram",
        "Name[uk]": "Додаток zstd",
        "Name[x-test]": "xxZstd pluginxx",
        "Name[zh_CN]": "Zstd 插件",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Priority": 100
}

==> ark-21.08.2.tar.xz: ark-21.08.2/plugins/libsinglefileplugin/kerfuffle_libzstd.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the zstd algorithm",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «zstd»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem zstd",
        "Description[da]": "Åbn og udpak enkelte filer komprimeret med zstd-algoritmen",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem zstd-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο zstd",
        "Description[en_GB]": "Open and extract single files compressed with the zstd algorithm",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo zstd",
        "Description[eu]": "Ireki eta erauzi zstd algoritmoarekin konprimatutako fitxategi bakunak",
        "Description[fr]": "Ouvrir et extraire des fichiers uniques compressés avec l'algorithme « zstd »",
        "Description[ia]": "Aperir e extraher singule files comprimite con le algorithmo zstd",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo zstd",
        "Description[ko]": "zstd 알고리즘으로 압축된 단일 파일 열고 풀기",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het zstd-algoritme",
        "Description[pl]": "Otwiera i wypakowuje pojedyncze pliki spakowane algorytmem zstd",
        "Description[pt_BR]": "Abrir e extrair arquivos individuais compactados com o algoritmo zstd",
        "Description[ro]": "Deschide și extrage fișiere singulare comprimate cu algoritmul zstd",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму zstd",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom zstd",
        "Description[sl]": "Odpri in razširi posamezne datoteke stisnjene z algoritmom zstd",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med zstd-algoritmen",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму zstd",
        "Description[x-test]": "xxOpen and extract single files compressed with the zstd algorithmxx",
        "Description[zh_CN]": "打开和解压 zstd 算法压缩的单个文件",
        "Id": "kerfuffle_libzstd",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Zstd plugin",
        "Name[ca]": "Connector del Zstd",
        "Name[cs]": "Modul pro zstd",
        "Name[da]": "Zstd-plugin",
        "Name[de]": "Zstd-Modul",
        "Name[el]": "Πρόσθετο zstd",
        "Name[en_GB]": "Zstd plugin",
        "Name[es]": "Complemento Zstd",
        "Name[eu]": "Zstd plugina",
        "Name[fr]": "Module externe « Zstd »",
        "Name[ia]": "Plugin de Zstd",
        "Name[it]": "Estensione zstd",
        "Name[ko]": "Zstd 플러그인",
        "Name[nl]": "Zstd-plug-in",
        "Name[pl]": "Wtyczka Zstd",
        "Name[pt_BR]": "Plugin Zstd",
        "Name[ro]": "Extensie Zstd",
        "Name[ru]": "Модуль Zstd",
        "Name[sk]": "Zstd plugin",
        "Name[sl]": "Vstavek Zstd",
        "Name[sv]": "Zstd-insticksprogram",
        "Name[uk]": "Додаток zstd",
        "Name[x-test]": "xxZstd pluginxx",
        "Name[zh_CN]": "Zstd 插件",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Priority": 100
}
